@@ -85,6 +85,7 @@ __all__ = (
     "JobSummaryTypeDef",
     "JobTimeoutTypeDef",
     "KeyValuePairTypeDef",
+    "KeyValuesPairTypeDef",
     "LaunchTemplateSpecificationTypeDef",
     "LinuxParametersTypeDef",
     "ListJobsRequestRequestTypeDef",
@@ -740,6 +741,7 @@ _OptionalJobSummaryTypeDef = TypedDict(
         "container": "ContainerSummaryTypeDef",
         "arrayProperties": "ArrayPropertiesSummaryTypeDef",
         "nodeProperties": "NodePropertiesSummaryTypeDef",
+        "jobDefinition": str,
     },
     total=False,
 )
@@ -766,6 +768,15 @@ KeyValuePairTypeDef = TypedDict(
     total=False,
 )
 
+KeyValuesPairTypeDef = TypedDict(
+    "KeyValuesPairTypeDef",
+    {
+        "name": str,
+        "values": List[str],
+    },
+    total=False,
+)
+
 LaunchTemplateSpecificationTypeDef = TypedDict(
     "LaunchTemplateSpecificationTypeDef",
     {
@@ -798,6 +809,7 @@ ListJobsRequestRequestTypeDef = TypedDict(
         "jobStatus": JobStatusType,
         "maxResults": int,
         "nextToken": str,
+        "filters": List["KeyValuesPairTypeDef"],
     },
     total=False,
 )
